#' @import utils
globalVariables(c(
  "eem",
  ".",
  "samp",
  "S275_295",
  "S350_400",
  "wavelength",
  "a250",
  "a365",
  "a465",
  "a665",
  "ex",
  "em",
  "eemnam",
  "eem_list",
  "comp",
  "amount",
  "value",
  "component",
  "comps",
  "fit",
  "leverage",
  "x",
  "label",
  "max_pos",
  "max_em",
  "max_ex",
  "emn",
  "exn",
  "type",
  "Sample",
  "em2",
  "e",
  "selection",
  "comp1",
  "o",
  "comp2",
  "tcc_em",
  "tcc_ex",
  "set",
  "y",
  "comb",
  "Freq",
  "parameter",
  "meta",
  "i",
  "z",
  "mod_name",
  "control",
  "modname",
  "B",
  "C",
  "TCC",
  "emission",
  "excitation",
  "spec",
  "spectrum",
  "wl",
  "absorbance",
  "error",
  "SAE",
  "em_max",
  "em_min",
  "ex_max",
  "ex_min",
  "name",
  "peaks"
), package = "staRdom")
